rcolor 0.0.1-beta
=================

>## Descripcion

> Sencillo script que permite introducir texto y el color con el que se imprimira en pantalla ese texto.

### Demo
[![asciicast](https://asciinema.org/a/p9li1MDwph2uyfA9Kk0bVgyED.png)](https://asciinema.org/a/p9li1MDwph2uyfA9Kk0bVgyED)